// Decompiled by Jad v1.5.8e. Copyright 2001 Pavel Kouznetsov.
// Jad home page: http://www.geocities.com/kpdus/jad.html
// Decompiler options: packimports(3) 
// Source File Name:   kinejava.java

package kinematics;


class Particle
{

    Particle(double d, String s, int i)
    {
        mass = d;
        label = s;
        charge = i;
    }

    double mass;
    String label;
    int charge;
    static final Particle list[] = {
        new Particle(0.0D, "gamma", 0), new Particle(0.13956995D, "Pi+", 1), new Particle(0.1349764D, "Pi0", 0), new Particle(0.13956995D, "Pi-", -1), new Particle(0.93827231D, "p", 1), new Particle(0.93956563000000004D, "n", 0), new Particle(1.87561339D, "d", 1), new Particle(2.808392D, "3He", 2), new Particle(3.7273800000000001D, "4He", 2), new Particle(9.3255060000000007D, "10Be", 4), 
        new Particle(10.252551D, "11B", 5), new Particle(10.254022000000001D, "11C", 6), new Particle(11.174866D, "12C", 6), new Particle(13.040874000000001D, "14C", 6), new Particle(13.971182000000001D, "15O", 8), new Particle(14.895084000000001D, "16O", 8), new Particle(0.00051099890000000001D, "e+", 1), new Particle(0.00051099890000000001D, "e-", -1), new Particle(0.10565835699999999D, "mu+", 1), new Particle(0.10565835699999999D, "mu-", -1)
    };

}
