// Decompiled by Jad v1.5.8e. Copyright 2001 Pavel Kouznetsov.
// Jad home page: http://www.geocities.com/kpdus/jad.html
// Decompiler options: packimports(3) 
// Source File Name:   kinejava.java

package kinematics;

import java.awt.*;

// Referenced classes of package kinematics:
//            mybar, mylabel, myunit

class varbar extends Panel
{

    public Dimension getPreferredSize()
    {
        return new Dimension(600, 40);
    }

    double getdouble()
    {
        return (new Double(tf.getText())).doubleValue();
    }

    public varbar(String s, int i, int j, String s1)
    {
        setBackground(new Color(128, 128, 128));
        setLayout(new FlowLayout());
        sb = new mybar(i, j);
        tf = new TextField(s, 8);
        tf.setFont(new Font("Times New Roman", 0, 14));
        tf.setEditable(true);
        mylabel mylabel1 = new mylabel(s);
        add(sb);
        add(new mylabel(s));
        add(tf);
        add(new myunit(s1));
    }

    Scrollbar sb;
    TextField tf;
    TextField unit;
}
