// Decompiled by Jad v1.5.8e. Copyright 2001 Pavel Kouznetsov.
// Jad home page: http://www.geocities.com/kpdus/jad.html
// Decompiler options: packimports(3) 
// Source File Name:   kinejava.java

package kinematics;

import java.awt.Dimension;
import java.awt.Scrollbar;

class mybar extends Scrollbar
{

    public Dimension getPreferredSize()
    {
        return new Dimension(250, 20);
    }

    public mybar(int i, int j)
    {
        super(0, i, 10, 0, j + 10);
    }
}
