// Decompiled by Jad v1.5.8e. Copyright 2001 Pavel Kouznetsov.
// Jad home page: http://www.geocities.com/kpdus/jad.html
// Decompiler options: packimports(3) 
// Source File Name:   kinejava.java

package kinematics;

import java.awt.*;

class mylabel extends Label
{

    public Dimension getPreferredSize()
    {
        return new Dimension(90, 29);
    }

    mylabel(String s)
    {
        super(s, 2);
        setFont(fnt);
    }

    static final Font fnt = new Font("Times New Roman", 0, 14);

}
