// Decompiled by Jad v1.5.8e. Copyright 2001 Pavel Kouznetsov.
// Jad home page: http://www.geocities.com/kpdus/jad.html
// Decompiler options: packimports(3) 
// Source File Name:   kinejava.java

package kinematics;

import java.awt.*;

// Referenced classes of package kinematics:
//            kinejava, varbar

class reactiondef extends Frame
{

    reactiondef(kinejava kinejava1)
    {
        super("Reaction Definition");
        setFont(new Font("Times New Roman", 0, 14));
        kj = kinejava1;
        setLayout(new GridLayout(4, 1));
        kj.chtarget = new Choice();
        kj.chtarget.addItem("Proton");
        kj.chtarget.addItem("Deuteron");
        kj.chtarget.addItem("3He");
        kj.chtarget.addItem("4He");
        kj.chtarget.addItem("12C");
        kj.chtarget.addItem("16O");
        kj.chmass1 = new Choice();
        kj.chmass1.addItem("Photon");
        kj.chmass1.addItem("Pion+");
        kj.chmass1.addItem("Pion0");
        kj.chmass1.addItem("Pion-");
        kj.chmass1.addItem("Proton");
        kj.chmass1.addItem("Neutron");
        kj.chmass1.addItem("Deuteron");
        kj.chmass1.addItem("3He");
        kj.chmass1.addItem("4He");
        kj.chmass1.addItem("10Be");
        kj.chmass1.addItem("11B");
        kj.chmass1.addItem("11C");
        kj.chmass1.addItem("12C");
        kj.chmass1.addItem("14C");
        kj.chmass1.addItem("15O");
        kj.chmass1.addItem("16O");
        kj.chmass2 = new Choice();
        kj.chmass2.addItem("Photon");
        kj.chmass2.addItem("Pion+");
        kj.chmass2.addItem("Pion0");
        kj.chmass2.addItem("Pion-");
        kj.chmass2.addItem("Proton");
        kj.chmass2.addItem("Neutron");
        kj.chmass2.addItem("Deuteron");
        kj.chmass2.addItem("e-");
        kj.chmass2.addItem("mu-");
        kj.chmass3 = new Choice();
        kj.chmass3.addItem("Photon");
        kj.chmass3.addItem("Pion+");
        kj.chmass3.addItem("Pion0");
        kj.chmass3.addItem("Pion-");
        kj.chmass3.addItem("Proton");
        kj.chmass3.addItem("Neutron");
        kj.chmass3.addItem("Deuteron");
        kj.chmass3.addItem("e+");
        kj.chmass3.addItem("mu+");
        Panel panel = new Panel();
        panel.add(new Label("gamma* + "));
        panel.add(kj.chtarget);
        panel.add(new Label(" -> "));
        panel.add(kj.chmass1);
        panel.add(new Label(" + X"));
        Panel panel1 = new Panel();
        panel1.add(new Label("Decay:  X -> "));
        panel1.add(kj.chmass2);
        panel1.add(new Label(" + "));
        panel1.add(kj.chmass3);
        add(panel);
        add(panel1);
        add(kj.vb_submass);
        add(kj.vb_thetadecay);
        kj.chtarget.addItemListener(kj);
        kj.chmass1.addItemListener(kj);
        kj.chmass2.addItemListener(kj);
        kj.chmass3.addItemListener(kj);
        kj.vb_submass.sb.addAdjustmentListener(kj);
        kj.vb_thetadecay.sb.addAdjustmentListener(kj);
        kj.vb_submass.tf.addActionListener(kj);
        kj.vb_thetadecay.tf.addActionListener(kj);
        pack();
    }

    kinejava kj;
}
